@@ -20,6 +20,9 @@ from sqlalchemy.types import Boolean, String
 from sqlalchemy.util import OrderedDict
 
 # The generic ARRAY type was introduced in SQLAlchemy 1.1
+from api_logic_server_cli.create_from_model.model_creation_services import Resource, ResourceRelationship, \
+    ResourceAttribute
+
 try:
     from sqlalchemy import ARRAY
 except ImportError:
@@ -208,6 +211,7 @@ class ModelClass(Model):
         self.name = self._tablename_to_classname(table.name, inflect_engine)
         self.children = []
         self.attributes = OrderedDict()
+        self.foreign_key_relationships = list()
 
         # Assign attribute names for columns
         for column in table.columns:
@@ -254,6 +258,10 @@ class ModelClass(Model):
         return _re_invalid_identifier.sub("_", name)
 
     def _add_attribute(self, attrname, value):
+        """ add table column/relationship to attributes
+
+        disambiguate relationship accessor names (append tablename with 1, 2...)
+        """
         attrname = tempname = self._convert_to_valid_identifier(attrname)
         counter = 1
         while tempname in self.attributes:
@@ -288,6 +296,7 @@ class ManyToOneRelationship(Relationship):
         column_names = _get_column_names(constraint)
         colname = column_names[0]
         tablename = constraint.elements[0].column.table.name
+        self.foreign_key_constraint = constraint
         if not colname.endswith('_id'):
             self.preferred_name = inflect_engine.singular_noun(tablename) or tablename
         else:
@@ -301,7 +310,11 @@ class ManyToOneRelationship(Relationship):
 
         # Handle self referential relationships
         if source_cls == target_cls:
-            self.preferred_name = 'parent' if not colname.endswith('_id') else colname[:-3]
+            # self.preferred_name = 'parent' if not colname.endswith('_id') else colname[:-3]
+            if colname.endswith("id") or colname.endswith("Id"):
+                self.preferred_name = colname[:-2]
+            else:
+                self.preferred_name = "parent"  # hmm, why not just table name
             pk_col_names = [col.name for col in constraint.table.primary_key]
             self.kwargs['remote_side'] = '[{0}]'.format(', '.join(pk_col_names))
 
@@ -364,9 +377,11 @@ class CodeGenerator(object):
 
 
 {models}"""
+    do_model_creation_services_hack = False
 
     def __init__(self, metadata, noindexes=False, noconstraints=False, nojoined=False,
-                 noinflect=False, noclasses=False, indentation='    ', model_separator='\n\n',
+                 noinflect=False, noclasses=False, model_creation_services = None,
+                 indentation='    ', model_separator='\n\n',
                  ignored_tables=('alembic_version', 'migrate_version'), table_model=ModelTable,
                  class_model=ModelClass,  template=None, nocomments=False):
         super(CodeGenerator, self).__init__()
@@ -376,12 +391,17 @@ class CodeGenerator(object):
         self.nojoined = nojoined
         self.noinflect = noinflect
         self.noclasses = noclasses
+        self.model_creation_services = model_creation_services  # ApiLogicServer
         self.indentation = indentation
         self.model_separator = model_separator
         self.ignored_tables = ignored_tables
         self.table_model = table_model
         self.class_model = class_model
         self.nocomments = nocomments
+        self.children_map = dict()
+        """ key is table name, value is list of (parent-role-name, child-role-name, relationship) ApiLogicServer """
+        self.parents_map = dict()
+        """ key is table name, value is list of (parent-role-name, child-role-name, relationship) ApiLogicServer """
         self.inflect_engine = self.create_inflect_engine()
         if template:
             self.template = template
@@ -451,7 +471,7 @@ class CodeGenerator(object):
                 model = self.table_model(table)
             else:
                 model = self.class_model(table, links[table.name], self.inflect_engine,
-                                         not nojoined)
+                                         not nojoined)  # computes attrs (+ roles)
                 classes[model.name] = model
 
             self.models.append(model)
@@ -710,6 +730,18 @@ from sqlalchemy.dialects.mysql import *
         rendered = 'class {0}(SAFRSBase, {1}):\n'.format(model.name, model.parent_name)   # ApiLogicServer
         rendered += '{0}__tablename__ = {1!r}\n'.format(self.indentation, model.table.name)
 
+        if self.do_model_creation_services_hack and not self.model_creation_services.resource_list_complete:
+            resource_list = self.model_creation_services.resource_list
+            resource = Resource(name=model.name)
+            for each_attr, each_column in model.attributes.items():
+                if isinstance(each_column, Column):
+                    resource_attribute = ResourceAttribute(name=str(each_column.name))
+                    resource.attributes.append(resource_attribute)
+            resource_list[model.name] = resource
+            if not str(model.table.name).startswith("ab_"):
+                self.model_creation_services.table_to_class_map_update(
+                    table_name=model.table.name, class_name=model.name)
+
         # Render constraints and indexes as __table_args__
         autonum_col = False
         table_args = []
@@ -768,10 +800,10 @@ from sqlalchemy.dialects.mysql import *
                 rel_render = "{0}{1} = {2}\n".format(self.indentation, attr, self.render_relationship(relationship))
                 rel_parts = rel_render.split(")")
                 backref_name = model.name + "List"
-                """ disambiguate multi-relns, eg,
-                    parent1 = relationship('AbUser', remote_side=[id],  <== goofy - should be AbUser
-                        primaryjoin='AbUser.created_by_fk == AbUser.id',
-                        cascade_backrefs=True, backref='AbUserList1')   <== need to append that "1"
+                """ disambiguate multi-relns, eg, in the Employee child class, 2 relns to Department:
+                        Department =  relationship('Department', primaryjoin='Employee.OnLoanDepartmentId == Department.Id', cascade_backrefs=True, backref='EmployeeList')
+                        Department1 = 'Department', primaryjoin='Employee.WorksForDepartmentId == Department.Id', cascade_backrefs=True, backref='EmployeeList_Department1')
+                    cascade_backrefs=True, backref='EmployeeList_Department1'   <== need to append that "1"
                 """
                 unique_name = relationship.target_cls + '.' + backref_name
                 if unique_name in backrefs:  # disambiguate
@@ -783,6 +815,46 @@ from sqlalchemy.dialects.mysql import *
                                           ")" + rel_parts[1]
                 # rendered += "{0}{1} = {2}\n".format(self.indentation, attr, self.render_relationship(relationship))
                 rendered += rel_render_with_backref
+                if relationship.source_cls.startswith("Ab"):
+                    pass
+                elif isinstance(relationship, ManyToManyRelationship):  # eg, chinook:PlayList->PlayListTrack
+                    pass  # fixme: admin.yaml not seeing ManyToManyRelationship
+                elif not self.do_model_creation_services_hack:
+                    pass
+                else:
+                    resource = self.model_creation_services.resource_list[relationship.source_cls]
+                    resource_relationship = ResourceRelationship(parent_role_name = attr,
+                                                                 child_role_name = backref_name)
+                    resource_relationship.child_resource = relationship.source_cls
+                    resource_relationship.parent_resource = relationship.target_cls
+                    # gen key pairs
+                    for each_pair in relationship.foreign_key_constraint.elements:
+                        pair = ( str(each_pair.column.name), str(each_pair.parent.name) )
+                        resource_relationship.parent_child_key_pairs.append(pair)
+
+                        resource.parents.append(resource_relationship)
+                        parent_resource = self.model_creation_services.resource_list[relationship.target_cls]
+                        parent_resource.children.append(resource_relationship)
+
+                        use_old_code = True  # so you can elide this
+                        if use_old_code:
+                            if relationship.source_cls not in self.parents_map:   # todo old code remove
+                                self.parents_map[relationship.source_cls] = list()
+                            self.parents_map[relationship.source_cls].append(
+                                (
+                                    attr,          # to parent, eg, Department, Department1
+                                    backref_name,  # to children, eg, EmployeeList, EmployeeList_Department1
+                                    relationship.foreign_key_constraint
+                                ) )
+                            if relationship.target_cls not in self.children_map:
+                                self.children_map[relationship.target_cls] = list()
+                            self.children_map[relationship.target_cls].append(
+                                (
+                                    attr,          # to parent, eg, Department, Department1
+                                    backref_name,  # to children, eg, EmployeeList, EmployeeList_Department1
+                                    relationship.foreign_key_constraint
+                                ) )
+                pass
 
         # Render subclasses
         for child_class in model.children:
@@ -791,6 +863,8 @@ from sqlalchemy.dialects.mysql import *
         return rendered
 
     def render(self, outfile=sys.stdout):
+        """ create model from db, and write models.py file to disk
+        """
         rendered_models = []
         for model in self.models:
             if isinstance(model, self.class_model):
