@@ -1,6 +1,8 @@
+import logging
+
 import util
 from typing import List
-import logging
+
 import safrs
 import sqlalchemy
 from flask import request, jsonify
@@ -16,11 +18,13 @@ from database.db import Base
 
 app_logger = logging.getLogger("api_logic_server_app")
 
-def expose_services(app, api, project_dir):
+
+def expose_services(app, api, project_dir, HOST: str, PORT: str):
+    """ extend model end points with new end points for services """
     app_logger.info("api/customize_api.py - expose custom services")
 
     @app.route('/hello_world')
-    def hello_world():  # test it with: http://localhost:5000/hello_world?user=ApiLogicServer
+    def hello_world():  # test it with: http://api_logic_server_host:api_logic_server_port/hello_world?user=ApiLogicServer
         """
         This is inserted to illustrate that APIs not limited to database objects, but are extensible.
 
@@ -34,5 +38,5 @@ def expose_services(app, api, project_dir):
     app_logger.info(f'*** Customizable ApiLogicServer project created -- '
              f'open it in your IDE at {project_dir}')
     app_logger.info(f'*** Server now running -- '
-             f'explore with OpenAPI (Swagger) at http://localhost:5000/')
+             f'explore with OpenAPI (Swagger) at http://{HOST}:{PORT}/')
     app_logger.info("\n")
\ No newline at end of file
