@@ -6,7 +6,7 @@
 
   $ python3 api_logic_server_run.py [Listener-IP]
 
-  This will run on http://Listener-Ip:5000
+  This will run on http://Listener-Ip:api_logic_server_port
 
 """
 import os
@@ -21,6 +21,7 @@ if len(sys.argv) > 1 and sys.argv[1].__contains__("help"):
 current_path = os.path.abspath(os.path.dirname(__file__))
 sys.path.append(current_path)
 project_dir = str(current_path)
+os.chdir(project_dir)  # so admin app can find images, code
 
 import logging
 app_logger = logging.getLogger('api_logic_server_app')
@@ -30,7 +31,8 @@ handler.setFormatter(formatter)
 app_logger.addHandler(handler)
 app_logger.propagate = True
 
-app_logger.setLevel(logging.INFO)  # use WARNING to reduce output
+app_logger.setLevel(logging.DEBUG)  # use WARNING to reduce output
+app_logger.info(f'app started: {__file__}\n')
 
 import threading
 import time
@@ -47,9 +49,8 @@ import socket
 from api import expose_api_models, customize_api
 from logic import declare_logic
 
-from flask import render_template, request, jsonify, Flask
+from flask import render_template, request, jsonify, Flask, redirect, send_from_directory
 from safrs import ValidationError, SAFRSBase
-import test.server_startup_test as self_test
 
 
 def is_docker():
@@ -78,7 +79,7 @@ def setup_logging(flask_app):
             formatter = logging.Formatter('%(message)s - %(asctime)s - %(name)s - %(levelname)s')
         handler.setFormatter(formatter)
         logic_logger.addHandler(handler)
-        logic_logger.setLevel(logging.DEBUG)
+        logic_logger.setLevel(logging.INFO)
         logic_logger.propagate = True
 
     do_engine_logging = False
@@ -122,7 +123,7 @@ def create_app(config_filename=None):
             detail = {"model": logic_row.name}
         raise ValidationErrorExt(message= message, detail=detail)
 
-    flask_app = Flask("API Logic Server")
+    flask_app = Flask("API Logic Server", template_folder='ui/templates')  # templates to load ui/admin/admin.yaml
     flask_app.config.from_object("config.Config")
     setup_logging(flask_app)
     db = safrs.DB  # opens database per config, setting session
@@ -133,8 +134,8 @@ def create_app(config_filename=None):
 
     with flask_app.app_context():
         db.init_app(flask_app)
-        safrs_api = expose_api_models.expose_models(flask_app, HOST=host)   # services from models
-        customize_api.expose_services(flask_app, safrs_api, project_dir)    # custom services
+        safrs_api = expose_api_models.expose_models(flask_app, HOST=host, PORT=port, API_PREFIX = API_PREFIX)
+        customize_api.expose_services(flask_app, safrs_api, project_dir, HOST=host, PORT=port)    # custom services
         SAFRSBase._s_auto_commit = False
         session.close()
 
@@ -155,13 +156,39 @@ flask_host = host
 if is_docker() and host == "localhost":
     flask_host = "0.0.0.0"
     app_logger.debug(f'==> Network Diagnostic - using docker flask_host: {flask_host}')
-port = "api_logic_server_port"
+if sys.argv[2:]:
+    port = sys.argv[2]  # you many need to enable cors support, below
+    app_logger.debug(f'==> Network Diagnostic - using specified port: {sys.argv[2]}')
+else:
+    port = "api_logic_server_port"
+
+API_PREFIX = "/api"
+did_send_spa = False
 flask_app, safrs_api = create_app()
 
 
 @flask_app.route('/')
-def welcome():
-    return render_template('index.html')
+def index():
+    app_logger.debug(f'API Logic Server - redirect /admin-app/index.html')
+    return redirect('/admin-app/index.html')
+
+
+@flask_app.route('/ui/admin/admin.yaml')
+def admin(path=None):  # test http://localhost/ui/admin/admin.yaml
+    with open("ui/admin/admin.yaml", "r") as f:
+        content = f.read()
+    app_logger.debug(f'loading ui/admin/admin.yaml')
+    return render_template('content.html', content=content)
+
+
+@flask_app.route("/admin-app/<path:path>")
+def send_spa(path=None):
+    global did_send_spa
+    directory = 'ui/admin'
+    if not did_send_spa:
+        did_send_spa = True
+        app_logger.debug(f'send_spa - directory = {directory}, path= {path}')
+    return send_from_directory(directory, path)
 
 
 @flask_app.errorhandler(ValidationError)
@@ -176,7 +203,7 @@ def handle_exception(e: ValidationError):
     return res, 400
 
 
-""" enable for cors support
+""" uncomment to disable cors support"""
 @flask_app.after_request
 def after_request(response):
     '''
@@ -191,43 +218,15 @@ def after_request(response):
         "Accept, Content-Type, Content-Length, Accept-Encoding, X-CSRF-Token, Authorization"
     # print(f'cors aftter_request - response: {str(response)}')
     return response
-"""
-
-
-@flask_app.before_first_request
-def run_before_first_request():
-    ''' start_runner pings server, starts this (1 ping only, Visily)
-    '''
-    def run_server_start_test():
-        self_test.server_tests(host, port, "api_logic_server_version")
-
-    thread = threading.Thread(target=run_server_start_test)
-    thread.start()
-
-
-def one_ping_on_server_start_for_server_start_tests():
-    """
-    On server start: 1 ping only, Visily
-
-    This executes @flask_app.before_first_request
-    """
-    def start_loop():
-        not_started = True
-        while not_started:
-            try:
-                r = requests.get(f'http://{host}:5000/')
-                if r.status_code == 200:
-                    not_started = False
-            except:
-                pass  # server not started, not a problem
-            time.sleep(2)
-
-    thread = threading.Thread(target=start_loop)
-    thread.start()
+""" """
 
 
 if __name__ == "__main__":
-    if self_test.server_tests_enabled:  # see test/server_startup_test.py
-        one_ping_on_server_start_for_server_start_tests()
-    app_logger.info(f'Starting ApiLogicServer project, version api_logic_server_version on {flask_host}')
+    user_host = flask_host
+    if is_docker():
+        user_host = "localhost"
+    msg = f'Starting ApiLogicServer project, version api_logic_server_version on http://{user_host}:{port}'
+    if is_docker():
+        msg += f' on docker container'
+    app_logger.info(msg)
     flask_app.run(host=flask_host, threaded=False, port=port)
